
TODO: Improve this readme.

# Tabular Examples

Demonstrations of tabular reinforcement learning algorithms implemented with cherry.

Those examples are largely inspired by the methods, illustrations, and examples presented in the "RL book":

* Sutton, Richard, and Andrew Barto. 2018. Reinforcement Learning, Second Edition. The MIT Press.

## Requirements

* Gym, torch, and cherry installed.

## Examples Descriptions

### Q-Learning

**Status** Replicates Sutton & Barto's implementation of Figure 6.4.

### SARSA

**Status** Replicates Sutton & Barto's implementation.
